#include <bits/stdc++.h>

using namespace std;


const int MOD[] = {1000000007, 1000000009};

struct Hash {
    int val[2];
    Hash(long long x = 0) {
        for (int i = 0; i <= 1; i++) {
            val[i] = x % MOD[i];
            if (val[i] < 0) val[i] += MOD[i];
        }
    }
};

Hash operator+(const Hash &a, const Hash &b) {
    Hash res;
    for (int i = 0; i <= 1; i++) {
        res.val[i] = (a.val[i] + b.val[i]) % MOD[i];
    }

    return res;
}

Hash operator-(const Hash &a, const Hash &b) {
    Hash res;
    for (int i = 0; i <= 1; i++) {
        res.val[i] = (a.val[i] + MOD[i] - b.val[i]) % MOD[i];
    }

    return res;
}

Hash operator*(const Hash &a, const Hash &b) {
    Hash res;
    for (int i = 0; i <= 1; i++) {
        res.val[i] = ((long long) a.val[i] * b.val[i]) % MOD[i];
    }

    return res;
}

bool operator==(const Hash &a, const Hash &b) {
    return make_pair(a.val[0], a.val[1]) == make_pair(b.val[0], b.val[1]);
}

struct Hasher {
    vector <Hash> P;
    vector <Hash> sufHash, revHash;

    Hasher(const string &s) {
        int n = s.size();

        sufHash.resize(n+1, 0);
        revHash.resize(n+1, 0);
        P.resize(n+1, 0);

        P[0] = 500009;

        for (int i = 1; i <= n; i++) {
            P[i] = P[0] * P[i-1];
        }

        for (int i = n - 1; i >= 0; i--) {
            sufHash[i] = P[0] * sufHash[i+1] + s[i];
        }

        for (int i = 0; i < n; i++) {
            revHash[i+1] = P[0] * revHash[i] + s[i];
        }
    }

    Hash getHash(int a, int b) {
        return sufHash[a] - P[b-a] * sufHash[b+1];
    }

    Hash getRevHash(int a, int b) {
        return revHash[b+1] - P[b-a] * revHash[a];
    }

    bool isPalindrome(int a, int b) {
        return (getHash(a,b) == getRevHash(a,b));
    }
};

string toString(const vector <int> &vec) {
    string res;
    for (auto b : vec) {
        res.push_back('0' + b);
    }

    return res;
}

bool check(const string &s, const vector <int> &arr) {
    int n = s.size();
    Hasher hasher(s);

    for (int i = 0; i < n; i++) {
        int ub = min(i + 1, n - i);
        if (arr[i] > ub) {
            return false;
        }

        if (arr[i] < ub && s[i - arr[i]] == s[i + arr[i]]) {
            return false;
        }

        if (!hasher.isPalindrome(i - arr[i] + 1, i + arr[i] - 1)) {
            return false;
        }
    }

    return true;
}

vector <string> solve(int n, const vector <int> &arr) {
    vector <string> ans;

    for (int first = 0; first <= 1; first++) {
        for (int second = 0; second <= 1; second++) {
            vector <int> curr = {first, second};

            for (int i = 2; i < n; i++) {
                curr.push_back(curr[i-2] xor (arr[i-1] == 1));
            }

            string sCurr = toString(curr);
            if (check(sCurr, arr)) {
                ans.push_back(sCurr);
            }
        }
    }

    return ans;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector <int> arr(n);
        for (int &x : arr) {
            cin >> x; x++;
        }

        auto ans = solve(n, arr);

        cout << ans.size() << '\n';
        for (auto &s : ans) {
            cout << s << '\n';
        }
    }
}
